Module input

Module input 

Input state collected from winit and exposed through Cotis interactivity traits.

InputSnapshot is updated by the renderer’s event loop on each cotis::renders::CotisRenderer::draw_frame / pump_events call. Cotis interactivity traits on crate::renderer::CotisWgpuRenderer (see crate::cotis_traits) read from this snapshot.

Structs

InputSnapshot
Snapshot of keyboard and mouse state for the current frame.