Module renderer

Module renderer 

CotisWgpuRenderer and window configuration for the wgpu backend.

This module owns the winit event loop, wgpu device/surface, and frame presentation logic. cotis::renders::CotisRenderer and cotis::renders::CotisRendererAsync trait implementations for CotisWgpuRenderer are defined at the bottom of this file; Cotis context and interactivity traits are in crate::cotis_traits.

Structs

CotisWgpuRenderer
wgpu-backed renderer implementing the shared cotis render traits.
WindowConfig
Window creation settings for CotisWgpuRenderer.